@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * The search helper for the node master
- *                                                      Copyright (C) 2004-2006 Mikio Hirabayashi
+ *                                                      Copyright (C) 2004-2007 Mikio Hirabayashi
  * This file is part of Hyper Estraier.
  * Hyper Estraier is free software; you can redistribute it and/or modify it under the terms of
  * the GNU Lesser General Public License as published by the Free Software Foundation; either
@@ -354,27 +354,27 @@ static int procsearch(const char *dbname, CBMAP *params, const char *outfile,
   end = max + skip;
   curtime = est_gettimeofday() - curtime;
   datum = cbdatumopen(NULL, -1);
-  est_datum_printf(datum, "%s\n", bordstr);
-  est_datum_printf(datum, "VERSION\t%s\n", _EST_PROTVER);
-  est_datum_printf(datum, "NODE\t%s\n", myurl);
-  est_datum_printf(datum, "HIT\t%d\n", hnum);
+  cbdatumprintf(datum, "%s\n", bordstr);
+  cbdatumprintf(datum, "VERSION\t%s\n", _EST_PROTVER);
+  cbdatumprintf(datum, "NODE\t%s\n", myurl);
+  cbdatumprintf(datum, "HIT\t%d\n", hnum);
   cbmapiterinit(hints);
   num = 1;
   while((kbuf = cbmapiternext(hints, &ksiz)) != NULL){
     if(ksiz < 1) continue;
-    est_datum_printf(datum, "HINT#%d\t%s\t%s\n", num, kbuf, cbmapiterval(kbuf, NULL));
+    cbdatumprintf(datum, "HINT#%d\t%s\t%s\n", num, kbuf, cbmapiterval(kbuf, NULL));
     num++;
   }
-  est_datum_printf(datum, "DOCNUM\t%d\n", dnum);
-  est_datum_printf(datum, "WORDNUM\t%d\n", wnum);
-  est_datum_printf(datum, "TIME\t%.6f\n", curtime / 1000.0);
-  est_datum_printf(datum, "TIME#i\t%.6f\n", itime / 1000.0);
-  est_datum_printf(datum, "TIME#0\t%.6f\n", curtime / 1000.0);
-  est_datum_printf(datum, "LINK#0\t%s\t", myurl);
-  est_datum_printf(datum, "%s\t%d\t%d\t%d\t%.0f\t%d\n",
-                   mylabel, SELFCREDIT, dnum, wnum, fsiz, hnum);
-  est_datum_printf(datum, "VIEW\tSNIPPET\n");
-  est_datum_printf(datum, "\n");
+  cbdatumprintf(datum, "DOCNUM\t%d\n", dnum);
+  cbdatumprintf(datum, "WORDNUM\t%d\n", wnum);
+  cbdatumprintf(datum, "TIME\t%.6f\n", curtime / 1000.0);
+  cbdatumprintf(datum, "TIME#i\t%.6f\n", itime / 1000.0);
+  cbdatumprintf(datum, "TIME#0\t%.6f\n", curtime / 1000.0);
+  cbdatumprintf(datum, "LINK#0\t%s\t", myurl);
+  cbdatumprintf(datum, "%s\t%d\t%d\t%d\t%.0f\t%d\n",
+                mylabel, SELFCREDIT, dnum, wnum, fsiz, hnum);
+  cbdatumprintf(datum, "VIEW\tSNIPPET\n");
+  cbdatumprintf(datum, "\n");
   phrase = est_cond_phrase(cond);
   order = est_cond_order(cond);
   if(!order && phrase && cbstrfwmatch(phrase, ESTOPSIMILAR))
@@ -384,15 +384,15 @@ static int procsearch(const char *dbname, CBMAP *params, const char *outfile,
   for(i = skip; i < rnum && i < end; i++){
     resdoc = resdocs[i];
     if(!resdoc->doc) continue;
-    est_datum_printf(datum, "%s\n", bordstr);
+    cbdatumprintf(datum, "%s\n", bordstr);
     list = est_doc_attr_names(resdoc->doc);
     for(j = 0; j < cblistnum(list); j++){
       vbuf = cblistval(list, j, NULL);
-      est_datum_printf(datum, "%s=%s\n", vbuf, est_doc_attr(resdoc->doc, vbuf));
+      cbdatumprintf(datum, "%s=%s\n", vbuf, est_doc_attr(resdoc->doc, vbuf));
     }
     cblistclose(list);
     if(smlrvnum > 0){
-      est_datum_printf(datum, "%s", ESTDCNTLVECTOR);
+      cbdatumprintf(datum, "%s", ESTDCNTLVECTOR);
       id = est_doc_id(resdoc->doc);
       kwords = id > 0 ? est_db_get_keywords(db, id) : NULL;
       if(!kwords) kwords = est_db_etch_doc(db, resdoc->doc, smlrvnum);
@@ -416,7 +416,7 @@ static int procsearch(const char *dbname, CBMAP *params, const char *outfile,
         cbdatumcat(datum, "\n", 1);
       }
       vbuf = est_doc_hidden_texts(resdoc->doc);
-      if(vbuf[0] != '\0')  est_datum_printf(datum, "\t%s\n", vbuf);
+      if(vbuf[0] != '\0')  cbdatumprintf(datum, "\t%s\n", vbuf);
     } else if(wwidth > 0){
       snippet = est_doc_make_snippet(resdoc->doc, words, wwidth, hwidth, awidth);
       cbdatumcat(datum, snippet, -1);
@@ -424,7 +424,7 @@ static int procsearch(const char *dbname, CBMAP *params, const char *outfile,
     }
   }
   free(resdocs);
-  est_datum_printf(datum, "%s:END\n", bordstr);
+  cbdatumprintf(datum, "%s:END\n", bordstr);
   if(!cbwritefile(outfile, cbdatumptr(datum), cbdatumsize(datum))) err = TRUE;
   cbdatumclose(datum);
   cblistclose(words);
