@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * The pseudo master of node servers
- *                                                      Copyright (C) 2004-2006 Mikio Hirabayashi
+ *                                                      Copyright (C) 2004-2007 Mikio Hirabayashi
  * This file is part of Hyper Estraier.
  * Hyper Estraier is free software; you can redistribute it and/or modify it under the terms of
  * the GNU Lesser General Public License as published by the Free Software Foundation; either
@@ -31,6 +31,7 @@ const char *g_indexdir = NULL;           /* path of the directory containing ind
 int g_runmode = 0;                       /* running mode */
 const char *g_pidxsuffix = NULL;         /* suffix of pseudo indexes */
 int g_pidxdocmax = -1;                   /* maximum number of documents in each pseudo index */
+int g_pidxdocmin = -1;                   /* minimum number of documents in each pseudo index */
 int g_lockindex = FALSE;                 /* whether to perform file locking to the database */
 int g_searchmax = 0;                     /* maximum number of documents to send */
 int g_rateuri = FALSE;                   /* whether to rate URI for scoring */
@@ -92,11 +93,9 @@ int main(int argc, char **argv){
   static int cnt = 0;
   est_proc_env_reset();
   while(FCGI_Accept() >= 0){
-    if(++cnt >= 64){
-      cbggcsweep();
-      cnt = 0;
-    }
     realmain(argc, argv);
+    fflush(stdout);
+    if(++cnt >= 64) exit(0);
   }
   return 0;
 #else
@@ -138,6 +137,8 @@ static int realmain(int argc, char **argv){
       g_pidxsuffix = skiplabel(rp);
     } else if(cbstrfwimatch(rp, "pidxdocmax:")){
       g_pidxdocmax = atoi(skiplabel(rp));
+    } else if(cbstrfwimatch(rp, "pidxdocmin:")){
+      g_pidxdocmin = atoi(skiplabel(rp));
     } else if(cbstrfwimatch(rp, "lockindex:")){
       g_lockindex = atoi(skiplabel(rp)) > 0;
     } else if(cbstrfwimatch(rp, "searchmax:")){
@@ -168,6 +169,7 @@ static int realmain(int argc, char **argv){
   if(g_runmode < RM_NORMAL || g_runmode > RM_RDONLY) die("runmode is undefined.");
   if(!g_pidxsuffix) die("pidxsuffix is undefined.");
   if(g_pidxdocmax < 0) die("pidxdocmax is undefined.");
+  if(g_pidxdocmin < 0) die("pidxdocmin is undefined.");
   if(g_searchmax < 0) die("searchmax is undefined.");
   if(g_rateuri < 0) die("rateuri is undefined.");
   if(g_mergemethod < 0) die("mergemethod is undefined.");
@@ -195,9 +197,9 @@ static int realmain(int argc, char **argv){
   cbmapout(params, PPOUTDOC, -1);
   cbmapout(params, PPPOSTCMD, -1);
   myurl = cbdatumopen(NULL, -1);
-  if((rp = getenv("HTTP_HOST")) != NULL) est_datum_printf(myurl, "http://%s", rp);
-  if((rp = getenv("SCRIPT_NAME")) != NULL) est_datum_printf(myurl, "%s", rp);
-  est_datum_printf(myurl, "/%s", idxname);
+  if((rp = getenv("HTTP_HOST")) != NULL) cbdatumprintf(myurl, "http://%s", rp);
+  if((rp = getenv("SCRIPT_NAME")) != NULL) cbdatumprintf(myurl, "%s", rp);
+  cbdatumprintf(myurl, "/%s", idxname);
   /* open the database */
   tmp = cbsprintf("%s%c%s", g_indexdir, ESTPATHCHR, idxname);
   omode = ESTDBREADER;
@@ -417,7 +419,7 @@ static void sendnodecmdsearch(ESTMTDB *db, const char *myurl, const char *mylabe
   const char *rp, *phrase, *order, *distinct, *bordstr, *kbuf, *vbuf;
   char name[NUMBUFSIZ], *snippet;
   int i, j, len, max, options, auxiliary, wwidth, hwidth, awidth, skip, lmax, rateuri;
-  int *res, rnum, hnum, cnt, score, down, dnum, wnum, end, num, id;
+  int *res, rnum, hnum, miss, cnt, score, down, dnum, wnum, end, num, id;
   double curtime, itime, weight, fsiz;
   if(!(phrase = cbmapget(params, "phrase", -1, NULL))) phrase = "";
   while(*phrase == ' ' || *phrase == '\t'){
@@ -450,7 +452,7 @@ static void sendnodecmdsearch(ESTMTDB *db, const char *myurl, const char *mylabe
   if(max > g_searchmax) max = g_searchmax;
   options = -1;
   if((rp = cbmapget(params, "options", -1, NULL)) != NULL) options = atoi(rp);
-  auxiliary = -1;
+  auxiliary = INT_MIN;
   if((rp = cbmapget(params, "auxiliary", -1, NULL)) != NULL) auxiliary = atoi(rp);
   if(!(distinct = cbmapget(params, "distinct", -1, NULL))) distinct = "";
   while(*distinct == ' ' || *distinct == '\t'){
@@ -477,7 +479,7 @@ static void sendnodecmdsearch(ESTMTDB *db, const char *myurl, const char *mylabe
   if(*order != '\0') est_cond_set_order(cond, order);
   if(options > 0) est_cond_set_options(cond, options);
   est_cond_set_options(cond, ESTCONDSCFB);
-  est_cond_set_auxiliary(cond, auxiliary);
+  if(auxiliary != INT_MIN) est_cond_set_auxiliary(cond, auxiliary);
   if(*distinct != '\0') est_cond_set_distinct(cond, distinct);
   resmap = resmap_new();
   hints = cbmapopenex(MINIBNUM);
@@ -491,6 +493,7 @@ static void sendnodecmdsearch(ESTMTDB *db, const char *myurl, const char *mylabe
     res = est_mtdb_search(db, cond, &rnum, hints);
     hnum = (vbuf = cbmapget(hints, "", 0, NULL)) ? atoi(vbuf) : rnum;
   }
+  miss = 0;
   itime = est_gettimeofday() - curtime;
   cnt = 0;
   rateuri = g_rateuri && !cbstrfwmatch(phrase, ESTOPSIMILAR);
@@ -499,6 +502,7 @@ static void sendnodecmdsearch(ESTMTDB *db, const char *myurl, const char *mylabe
     if(g_scancheck && *phrase != '\0' && *phrase != '[' &&
        res[i] < ESTPDOCIDMIN && !est_mtdb_scan_doc(db, doc, cond)){
       est_doc_delete(doc);
+      miss++;
       continue;
     }
     score = est_cond_score(cond, i);
@@ -570,7 +574,7 @@ static void sendnodecmdsearch(ESTMTDB *db, const char *myurl, const char *mylabe
   printf("%s\n", bordstr);
   printf("VERSION\t%s\n", _EST_PROTVER);
   printf("NODE\t%s\n", myurl);
-  printf("HIT\t%d\n", hnum);
+  printf("HIT\t%d\n", hnum - miss);
   cbmapiterinit(hints);
   num = 1;
   while((kbuf = cbmapiternext(hints, NULL)) != NULL){
@@ -584,7 +588,7 @@ static void sendnodecmdsearch(ESTMTDB *db, const char *myurl, const char *mylabe
   printf("TIME#i\t%.6f\n", itime / 1000.0);
   printf("TIME#0\t%.6f\n", curtime / 1000.0);
   printf("LINK#0\t%s\t", myurl);
-  printf("%s\t%d\t%d\t%d\t%.0f\t%d\n", mylabel, SELFCREDIT, dnum, wnum, fsiz, hnum);
+  printf("%s\t%d\t%d\t%d\t%.0f\t%d\n", mylabel, SELFCREDIT, dnum, wnum, fsiz, hnum - miss);
   printf("VIEW\tSNIPPET\n");
   printf("\n");
   if(*order == '\0' && cbstrfwmatch(phrase, ESTOPSIMILAR)) order = DATTRNDSCORE " " ESTORDNUMD;
@@ -754,8 +758,9 @@ static void sendnodecmduritoid(ESTMTDB *db, const char *myurl, const char *mylab
 static void sendnodecmdputdoc(ESTMTDB *db, const char *myurl, const char *mylabel,
                               CBMAP *params){
   ESTDOC *doc;
+  CBMAP *kwords;
   const char *draft, *uri;
-  char *tmp;
+  char *dbuf, *tmp;
   draft = cbmapget(params, "draft", -1, NULL);
   if(!draft){
     senderror(400, "Bad Request (the parameters lack)");
@@ -767,6 +772,14 @@ static void sendnodecmdputdoc(ESTMTDB *db, const char *myurl, const char *mylabe
     est_doc_delete(doc);
     return;
   }
+  dbuf = NULL;
+  if(g_smlrvnum > 0 && g_extdelay < 0 && !est_doc_keywords(doc)){
+    kwords = est_morph_etch_doc(doc, g_smlrvnum);
+    est_doc_set_keywords(doc, kwords);
+    cbmapclose(kwords);
+    dbuf = est_doc_dump_draft(doc);
+    draft = dbuf;
+  }
   tmp = cbsprintf("%s%s%c%012d%06d.est",
                   est_mtdb_name(db), g_pidxsuffix, ESTPATHCHR, (int)time(NULL), (int)getpid());
   if(cbwritefile(tmp, draft, -1)){
@@ -780,6 +793,7 @@ static void sendnodecmdputdoc(ESTMTDB *db, const char *myurl, const char *mylabe
     senderror(403, "Forbidden (writing a pseudo document failed)");
   }
   free(tmp);
+  free(dbuf);
   est_doc_delete(doc);
 }
 
@@ -971,7 +985,7 @@ static void procpostcmdsync(const char *idxname){
   CBLIST *list;
   const char *name;
   char *tmp, *draft;
-  int i, ecode;
+  int i, ecode, num;
   tmp = cbsprintf("%s%c%s", g_indexdir, ESTPATHCHR, idxname);
   if(!(db = est_mtdb_open(tmp, ESTDBWRITER, &ecode))){
     free(tmp);
@@ -983,7 +997,8 @@ static void procpostcmdsync(const char *idxname){
   free(tmp);
   if(list){
     cblistsort(list);
-    for(i = 0; i < cblistnum(list); i++){
+    num = cblistnum(list) - g_pidxdocmin;
+    for(i = 0; i < num; i++){
       name = cblistval(list, i, NULL);
       if(!strcmp(name, ESTCDIRSTR) || !strcmp(name, ESTPDIRSTR)) continue;
       tmp = cbsprintf("%s%c%s%s%c%s",
