@@ -530,15 +530,6 @@ void est_sock_recv_void(int sock);
 void est_sock_send_all(int sock, const char *buf, int len);
 
 
-/* Perform formatted output into a datum object.
-   `format' specifies a printf-like format string.
-   The conversion  character `%' can be used with such flag characters as `s', `d', `o', `u',
-   `x', `X', `c', `e', `E', `f', `g', `G', `@', `?', `%'.  `@' works as with `s' but escapes
-   meta characters of XML.  `?' works as with `s' but escapes meta characters of URL.  The other
-   conversion character work as with each original. */
-void est_datum_printf(CBDATUM *datum, const char *format, ...);
-
-
 /* Perform an interaction of a URL.
    `url' specifies a URL.
    `pxhost' specifies the host name of a proxy.  If it is `NULL', it is not used.
