@@ -1,6 +1,6 @@
 /*************************************************************************************************
  * A sample searcher of Hyper Estraier
- *                                                      Copyright (C) 2004-2006 Mikio Hirabayashi
+ *                                                      Copyright (C) 2004-2007 Mikio Hirabayashi
  * This file is part of Hyper Estraier.
  * Hyper Estraier is free software; you can redistribute it and/or modify it under the terms of
  * the GNU Lesser General Public License as published by the Free Software Foundation; either
@@ -98,8 +98,8 @@ int p_navi = NM_NORMAL;                  /* navigation mode */
 const char *p_phrase = NULL;             /* search phrase */
 const char *p_attr = NULL;               /* narrowing attribute */
 const char *p_attrval = NULL;            /* separated value of narrowing attribute */
-const char *p_order = NULL;              /* ordering attribute */
-int p_perpage = 0;                       /* number of show documents per page */
+const char *p_order = NULL;              /* ordering expression */
+int p_perpage = 0;                       /* number of shown documents per page */
 int p_clip = 0;                          /* lower limit of similarity eclipse */
 int p_qxpnd = FALSE;                     /* whether to perform query expansion */
 int p_gmasks = 0;                        /* masks for genre attributes */
@@ -158,11 +158,6 @@ int main(int argc, char **argv){
   static int cnt = 0;
   est_proc_env_reset();
   while(FCGI_Accept() >= 0){
-    if(++cnt >= 256){
-      cbggcsweep();
-      g_db = NULL;
-      cnt = 0;
-    }
     p_navi = NM_NORMAL;
     p_phrase = NULL;
     p_attr = NULL;
@@ -180,6 +175,8 @@ int main(int argc, char **argv){
     g_attrlist = NULL;
     g_hnum = -1;
     realmain(argc, argv);
+    fflush(stdout);
+    if(++cnt >= 256) exit(0);
   }
   return 0;
 #else
@@ -856,7 +853,7 @@ static void showpage(void){
     docs = cbmalloc(rnum * sizeof(ESTDOC *) + 1);
     dnum = 0;
     miss = 0;
-    check = g_scancheck;
+    check = p_phrase[0] == '\0' || p_phrase[0] == '[' ? 0 : g_scancheck;
     for(i = 0; i < rnum; i++){
       docs[dnum] = est_db_get_doc(g_db, res[i],
                                   dnum < p_pagenum * p_perpage || check > 0 ? 0 :
@@ -865,7 +862,7 @@ static void showpage(void){
         miss++;
         continue;
       }
-      if(check > 0 && p_phrase[0] != '[' && !est_db_scan_doc(g_db, docs[dnum], cond)){
+      if(check > 0 && !est_db_scan_doc(g_db, docs[dnum], cond)){
         est_doc_delete(docs[dnum]);
         miss++;
         continue;
